@@ -1,4 +1,4 @@
-/*  Copyright (c) 2003-2013 Xfce Development Team
+/*  Copyright (c) 2003-2014 Xfce Development Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -202,31 +202,48 @@ weather_dump_icon_theme(const icon_theme *theme)
 
 
 gchar *
-weather_dump_astrodata(const xml_astro *astro)
+weather_dump_astrodata(const GArray *astrodata)
 {
-    gchar *out, *sunrise, *sunset, *moonrise, *moonset;
+    GString *out;
+    gchar *result, *line;
+    xml_astro *astro;
+    gint i;
+
+    if (!astrodata || astrodata->len <= 0)
+        return g_strdup("No astronomical data available.");
+
+    out = g_string_sized_new(1024);
+    g_string_assign(out, "Astronomical data:\n");
+    for (i = 0; i < astrodata->len; i++) {
+        astro = g_array_index(astrodata, xml_astro *, i);
+        line = weather_dump_astro(astro);
+        g_string_append(out, line);
+        g_free(line);
+    }
+    /* Free GString only and return its character data */
+    result = out->str;
+    g_string_free(out, FALSE);
+    return result;
+}
+
+
+gchar *
+weather_dump_astro(const xml_astro *astro)
+{
+    gchar *out, *day, *sunrise, *sunset, *moonrise, *moonset;
 
     if (!astro)
-        return g_strdup("No astronomical data.");
+        return g_strdup("Astrodata: NULL.");
 
+    day = format_date(astro->day, "%c", TRUE);
     sunrise = format_date(astro->sunrise, "%c", TRUE);
     sunset = format_date(astro->sunset, "%c", TRUE);
     moonrise = format_date(astro->moonrise, "%c", TRUE);
     moonset = format_date(astro->moonset, "%c", TRUE);
 
-    out = g_strdup_printf("Astronomical data:\n"
-                          "  --------------------------------------------\n"
-                          "  sunrise: %s\n"
-                          "  sunset: %s\n"
-                          "  sun never rises: %s\n"
-                          "  sun never sets: %s\n"
-                          "  --------------------------------------------\n"
-                          "  moonrise: %s\n"
-                          "  moonset: %s\n"
-                          "  moon never rises: %s\n"
-                          "  moon never sets: %s\n"
-                          "  moon phase: %s\n"
-                          "  --------------------------------------------",
+    out = g_strdup_printf("day=%s, sun={%s, %s, %s, %s}, "
+                          "moon={%s, %s, %s, %s, %s}\n",
+                          day,
                           sunrise,
                           sunset,
                           YESNO(astro->sun_never_rises),
@@ -236,6 +253,8 @@ weather_dump_astrodata(const xml_astro *astro)
                           YESNO(astro->moon_never_rises),
                           YESNO(astro->moon_never_sets),
                           astro->moon_phase);
+
+    g_free(day);
     g_free(sunrise);
     g_free(sunset);
     g_free(moonrise);
@@ -305,13 +324,13 @@ weather_dump_units_config(const units_config *units)
                           "  Temperature: %d\n"
                           "  Atmospheric pressure: %d\n"
                           "  Windspeed: %d\n"
-                          "  Precipitations: %d\n"
+                          "  Precipitation: %d\n"
                           "  Altitude: %d\n"
                           "  --------------------------------------------",
                           units->temperature,
                           units->pressure,
                           units->windspeed,
-                          units->precipitations,
+                          units->precipitation,
                           units->altitude);
     return out;
 }
@@ -405,13 +424,12 @@ weather_dump_plugindata(const plugin_data *data)
     g_string_append_printf(out,
                            "  --------------------------------------------\n"
                            "  panel size: %d px\n"
-                           "  plugin size: %d px\n"
+                           "  panel rows: %d px\n"
+                           "  single row: %s\n"
                            "  panel orientation: %d\n"
-                           "  plugin orientation: %d\n"
                            "  --------------------------------------------\n"
 #ifdef HAVE_UPOWER_GLIB
                            "  upower on battery: %s\n"
-                           "  upower lid closed: %s\n"
 #endif
                            "  power saving: %s\n"
                            "  --------------------------------------------\n"
@@ -450,12 +468,11 @@ weather_dump_plugindata(const plugin_data *data)
                            "  animate scrollbox: %s\n"
                            "  --------------------------------------------",
                            data->panel_size,
-                           data->size,
+                           data->panel_rows,
+                           YESNO(data->single_row),
                            data->panel_orientation,
-                           data->orientation,
 #ifdef HAVE_UPOWER_GLIB
                            YESNO(data->upower_on_battery),
-                           YESNO(data->upower_lid_closed),
 #endif
                            YESNO(data->power_saving),
                            last_astro_update,
