@@ -1,4 +1,4 @@
-/*  Copyright (c) 2003-2013 Xfce Development Team
+/*  Copyright (c) 2003-2014 Xfce Development Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -57,6 +57,9 @@ typedef struct {
     time_t next;
     guint attempt;
     guint check_interval;
+    gboolean started;
+    gboolean finished;
+    guint http_status_code;
 } update_info;
 
 typedef struct {
@@ -82,11 +85,12 @@ typedef struct {
     guint summary_remember_tab;
 
     gint panel_size;
-    gint size;
-    GtkOrientation orientation;
+    guint panel_rows;
     GtkOrientation panel_orientation;
+    gboolean single_row;
     xml_weather *weatherdata;
-    xml_astro *astrodata;
+    GArray *astrodata;
+    xml_astro *current_astro;
 
     update_info *astro_update;
     update_info *weather_update;
@@ -149,6 +153,12 @@ void update_weatherdata_with_reset(plugin_data *data);
 
 GArray *labels_clear(GArray *array);
 
+#if LIBXFCE4PANEL_CHECK_VERSION(4,9,0)
+gboolean xfceweather_set_mode(XfcePanelPlugin *panel,
+                              XfcePanelPluginMode mode,
+                              plugin_data *data);
+#endif
+
 G_END_DECLS
 
 #endif
